// typescript
import typescript from 'rollup-plugin-typescript2';

// babel
import babel from '@rollup/plugin-babel';

// commonjs 模块解析
import commonjs from '@rollup/plugin-commonjs';

// node 模块解析
import { nodeResolve } from '@rollup/plugin-node-resolve';

// 代码压缩
import { terser } from 'rollup-plugin-terser';

import css from 'rollup-plugin-css-only';

// 图片处理
import image from '@rollup/plugin-image';

// .vue文件处理
import vue from 'rollup-plugin-vue';

// 自动加厂商前缀
import autoprefixer from 'autoprefixer';

// px转rem
import px2rem from 'postcss-plugin-px2rem';

export default {
  input: 'src/index.ts',
  external: [
    'vue',
    'vant'
  ],
  output: {
    format: 'umd',
    file: 'lib/components.umd.js',
    name: 'components',
    globals: {
      vue: 'Vue',
      vant: 'vant',
    },
  },
  plugins: [
    vue({
      template: {
        isProduction: true,
      },
      style: {
        postcssPlugins: [
          autoprefixer({
            grid: 'autoplace',
          }),
          px2rem({
            rootValue: 37.5,
            exclude: /(node_modules)|(plugins)/,
          }),
        ],
      },
    }),
    // 可以找到node环境的依赖
    nodeResolve(),

    // 解析 commonjs 模块
    commonjs(),
    image(),
    typescript(),
    babel({
      exclude: 'node_modules',
      babelHelpers: 'runtime',
      extensions: ['.js', '.jsx', '.ts', '.tsx', '.vue'],
      presets: [
        '@babel/preset-typescript',
        [
          '@babel/preset-env',
          {
            // modules: false,

            // 兼容老版本，实在没办法再打开吧
            // 一直打开打包出来的内容太大了
            // useBuiltIns: 'usage',
            // corejs: '3.19.1',

            // 目标浏览器
            targets: {
              edge: '10',
              firefox: '50',
              chrome: '50',
              safari: '7',
              ie: '8',
            },
          },
        ],
      ],
      plugins: [['@babel/plugin-transform-runtime']],
    }),
    terser(),
    css({
      output: 'components.min.css',
    }),
  ],
  // 循环依赖不显示
  onwarn(msg, warn) {
    if (!/Circular/.test(msg)) {
      warn(msg)
    }
  },
};
