export {
  Downloader,
  Parser,
  EVENT_TYPES,
  PLAY_MODE,
  FILL_MODE,
} from 'svga.lite';

export type Options = {
  /**
   * canvas 选择器
   */
  element: string;

  /**
   * svga 地址
   */
  src: string;

  /**
   * 是否缓存svga
   * IOS 上可能无法存取,或存取比较慢
   */
  cacheSvga?: boolean;

  /**
   * 取缓存的超时时间
   * 超过之后加载远程的svga
   */
  cacheTiemout?: number;

  /**
   * 循环次数
   * 为0时一直播放
   */
  loop?: number;

  /**
   * 最后停留的目标模式
   */
  fillMode?: FILL_MODE;

  /**
   * 播放顺序
   */
  playMode?: PLAY_MODE;

  /**
   * 开始帧
   */
  startFrame?: number;

  /**
   * 结束帧
   * 0为最后一帧
   */
  endFrame?: number;

  /**
   * 是否缓存帧
   * 缓存会占用内存，反而更卡
   */
  cacheFrames: boolean;

  /**
   * 是否开启动画容器视窗检测
   * 开启后利用 Intersection Observer API
   * 检测动画容器是否处于视窗内
   * 若处于视窗外，停止描绘渲染帧避免造成资源消耗
   */
  intersectionObserverRender: boolean;

  /**
   * 是否避免执行延迟
   * 使用 WebWorker 手机上反而更卡
   */
  noExecutionDelay?: boolean;

  /**
   * 事件监听
   */
  listener(type: string, data?: any): void | Proimse<void>;
};

/**
 * 实际使用的类型
 */
export type SvgaPlayerOptions = Omit<Options, {
  src,
  element,
}>;
